# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sliverpb/sliver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..commonpb import common_pb2 as commonpb_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sliverpb/sliver.proto',
  package='sliverpb',
  syntax='proto3',
  serialized_options=b'Z-github.com/bishopfox/sliver/protobuf/sliverpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15sliverpb/sliver.proto\x12\x08sliverpb\x1a\x15\x63ommonpb/common.proto\"N\n\x08\x45nvelope\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c\x12\x1a\n\x12UnknownMessageType\x18\x04 \x01(\x08\"\xed\x01\n\x08Register\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08Hostname\x18\x02 \x01(\t\x12\x0c\n\x04Uuid\x18\x03 \x01(\t\x12\x10\n\x08Username\x18\x04 \x01(\t\x12\x0b\n\x03Uid\x18\x05 \x01(\t\x12\x0b\n\x03Gid\x18\x06 \x01(\t\x12\n\n\x02Os\x18\x07 \x01(\t\x12\x0c\n\x04\x41rch\x18\x08 \x01(\t\x12\x0b\n\x03Pid\x18\t \x01(\x05\x12\x10\n\x08\x46ilename\x18\n \x01(\t\x12\x10\n\x08\x41\x63tiveC2\x18\x0b \x01(\t\x12\x0f\n\x07Version\x18\x0c \x01(\t\x12\x19\n\x11ReconnectInterval\x18\r \x01(\r\x12\x10\n\x08ProxyURL\x18\x0e \x01(\t\"_\n\x04Ping\x12\r\n\x05Nonce\x18\x01 \x01(\x05\x12$\n\x08Response\x18\x08 \x01(\x0b\x32\x12.commonpb.Response\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"C\n\x0eKillSessionReq\x12\r\n\x05\x46orce\x18\x01 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"+\n\x05PsReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"P\n\x02Ps\x12$\n\tProcesses\x18\x01 \x03(\x0b\x32\x11.commonpb.Process\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"N\n\x0cTerminateReq\x12\x0b\n\x03Pid\x18\x01 \x01(\x05\x12\r\n\x05\x46orce\x18\x02 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\">\n\tTerminate\x12\x0b\n\x03Pid\x18\x01 \x01(\x05\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"1\n\x0bIfconfigReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"_\n\x08Ifconfig\x12-\n\rNetInterfaces\x18\x01 \x03(\x0b\x32\x16.sliverpb.NetInterface\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"M\n\x0cNetInterface\x12\r\n\x05Index\x18\x01 \x01(\x05\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0b\n\x03MAC\x18\x03 \x01(\t\x12\x13\n\x0bIPAddresses\x18\x04 \x03(\t\"9\n\x05LsReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"k\n\x02Ls\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0e\n\x06\x45xists\x18\x02 \x01(\x08\x12!\n\x05\x46iles\x18\x03 \x03(\x0b\x32\x12.sliverpb.FileInfo\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"5\n\x08\x46ileInfo\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05IsDir\x18\x02 \x01(\x08\x12\x0c\n\x04Size\x18\x03 \x01(\x03\"9\n\x05\x43\x64Req\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\",\n\x06PwdReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"9\n\x03Pwd\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"[\n\x05RmReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x11\n\tRecursive\x18\x02 \x01(\x08\x12\r\n\x05\x46orce\x18\x03 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"8\n\x02Rm\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"<\n\x08MkdirReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\";\n\x05Mkdir\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"?\n\x0b\x44ownloadReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"m\n\x08\x44ownload\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0f\n\x07\x45ncoder\x18\x02 \x01(\t\x12\x0e\n\x06\x45xists\x18\x03 \x01(\x08\x12\x0c\n\x04\x44\x61ta\x18\x04 \x01(\x0c\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\\\n\tUploadReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0f\n\x07\x45ncoder\x18\x02 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"<\n\x06Upload\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"R\n\x0eProcessDumpReq\x12\x0b\n\x03Pid\x18\x01 \x01(\x05\x12\x0f\n\x07Timeout\x18\x02 \x01(\x05\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"A\n\x0bProcessDump\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"c\n\x08RunAsReq\x12\x10\n\x08Username\x18\x01 \x01(\t\x12\x13\n\x0bProcessName\x18\x02 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x03 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"=\n\x05RunAs\x12\x0e\n\x06Output\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"F\n\x0eImpersonateReq\x12\x10\n\x08Username\x18\x01 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"3\n\x0bImpersonate\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"2\n\x0cRevToSelfReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"1\n\tRevToSelf\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"^\n\x12InvokeGetSystemReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x16\n\x0eHostingProcess\x18\x02 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"1\n\tGetSystem\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"f\n\x0cMakeTokenReq\x12\x10\n\x08Username\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\x12\x0e\n\x06\x44omain\x18\x03 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"1\n\tMakeToken\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"k\n\x07TaskReq\x12\x0f\n\x07\x45ncoder\x18\x01 \x01(\t\x12\x10\n\x08RWXPages\x18\x02 \x01(\x08\x12\x0b\n\x03Pid\x18\x03 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x04 \x01(\x0c\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\",\n\x04Task\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\xc1\x01\n\x12\x45xecuteAssemblyReq\x12\x10\n\x08\x41ssembly\x18\x01 \x01(\x0c\x12\x11\n\tArguments\x18\x02 \x01(\t\x12\x0f\n\x07Process\x18\x03 \x01(\t\x12\r\n\x05IsDLL\x18\x04 \x01(\x08\x12\x0c\n\x04\x41rch\x18\x05 \x01(\t\x12\x11\n\tClassName\x18\x06 \x01(\t\x12\x0e\n\x06Method\x18\x07 \x01(\t\x12\x11\n\tAppDomain\x18\x08 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"]\n\x18InvokeExecuteAssemblyReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x0f\n\x07process\x18\x02 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"G\n\x0f\x45xecuteAssembly\x12\x0e\n\x06Output\x18\x01 \x01(\x0c\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"Q\n\x10InvokeMigrateReq\x12\x0b\n\x03Pid\x18\x01 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"@\n\x07Migrate\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\\\n\nExecuteReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x02 \x03(\t\x12\x0e\n\x06Output\x18\x03 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"a\n\x0f\x45xecuteTokenReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x02 \x03(\t\x12\x0e\n\x06Output\x18\x03 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"O\n\x07\x45xecute\x12\x0e\n\x06Result\x18\x01 \x01(\t\x12\x0e\n\x06Status\x18\x02 \x01(\r\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\x84\x01\n\x0bSideloadReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x13\n\x0bProcessName\x18\x02 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x03 \x01(\t\x12\x12\n\nEntryPoint\x18\x04 \x01(\t\x12\x0c\n\x04Kill\x18\x05 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"@\n\x08Sideload\x12\x0e\n\x06Result\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\x8a\x01\n\x11InvokeSpawnDllReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x13\n\x0bProcessName\x18\x02 \x01(\t\x12\x0c\n\x04\x41rgs\x18\x03 \x01(\t\x12\x12\n\nEntryPoint\x18\x04 \x01(\t\x12\x0c\n\x04Kill\x18\x05 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"\x80\x01\n\x0bSpawnDllReq\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x13\n\x0bProcessName\x18\x02 \x01(\t\x12\x0e\n\x06Offset\x18\x03 \x01(\r\x12\x0c\n\x04\x41rgs\x18\x04 \x01(\t\x12\x0c\n\x04Kill\x18\x05 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"@\n\x08SpawnDll\x12\x0e\n\x06Result\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"w\n\nNetstatReq\x12\x0b\n\x03TCP\x18\x01 \x01(\x08\x12\x0b\n\x03UDP\x18\x02 \x01(\x08\x12\x0b\n\x03IP4\x18\x03 \x01(\x08\x12\x0b\n\x03IP6\x18\x05 \x01(\x08\x12\x11\n\tListening\x18\x06 \x01(\x08\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"\xf1\x01\n\x0cSockTabEntry\x12\x32\n\tLocalAddr\x18\x01 \x01(\x0b\x32\x1f.sliverpb.SockTabEntry.SockAddr\x12\x33\n\nRemoteAddr\x18\x02 \x01(\x0b\x32\x1f.sliverpb.SockTabEntry.SockAddr\x12\x0f\n\x07SkState\x18\x03 \x01(\t\x12\x0b\n\x03UID\x18\x04 \x01(\r\x12\"\n\x07Process\x18\x05 \x01(\x0b\x32\x11.commonpb.Process\x12\x10\n\x08Protocol\x18\x06 \x01(\t\x1a$\n\x08SockAddr\x12\n\n\x02Ip\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\"X\n\x07Netstat\x12\'\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\x16.sliverpb.SockTabEntry\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\":\n\x06\x45nvReq\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"T\n\x07\x45nvInfo\x12#\n\tVariables\x18\x01 \x03(\x0b\x32\x10.commonpb.EnvVar\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"S\n\tSetEnvReq\x12\"\n\x08Variable\x18\x01 \x01(\x0b\x32\x10.commonpb.EnvVar\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\".\n\x06SetEnv\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\x1d\n\x0e\x44NSSessionInit\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\"3\n\x07\x44NSPoll\x12(\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x18.sliverpb.DNSBlockHeader\"*\n\x0e\x44NSBlockHeader\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\r\"\x1e\n\x0fHTTPSessionInit\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\"3\n\rScreenshotReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"@\n\nScreenshot\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\x9c\x01\n\x0fStartServiceReq\x12\x13\n\x0bServiceName\x18\x01 \x01(\t\x12\x1a\n\x12ServiceDescription\x18\x02 \x01(\t\x12\x0f\n\x07\x42inPath\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12\x11\n\tArguments\x18\x05 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"3\n\x0bServiceInfo\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"7\n\x0eServiceInfoReq\x12\x13\n\x0bServiceName\x18\x01 \x01(\t\x12\x10\n\x08Hostname\x18\x02 \x01(\t\"c\n\x0eStopServiceReq\x12-\n\x0bServiceInfo\x18\x01 \x01(\x0b\x32\x18.sliverpb.ServiceInfoReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"e\n\x10RemoveServiceReq\x12-\n\x0bServiceInfo\x18\x01 \x01(\x0b\x32\x18.sliverpb.ServiceInfoReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"X\n\x0b\x42\x61\x63kdoorReq\x12\x10\n\x08\x46ilePath\x18\x01 \x01(\t\x12\x13\n\x0bProfileName\x18\x02 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"0\n\x08\x42\x61\x63kdoor\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"p\n\x0fRegistryReadReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"C\n\x0cRegistryRead\x12\r\n\x05Value\x18\x01 \x01(\t\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"\xe7\x01\n\x10RegistryWriteReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12\x13\n\x0bStringValue\x18\x05 \x01(\t\x12\x11\n\tByteValue\x18\x06 \x01(\x0c\x12\x12\n\nDWordValue\x18\x07 \x01(\r\x12\x12\n\nQWordValue\x18\x08 \x01(\x04\x12$\n\x04Type\x18\n \x01(\x0e\x32\x16.sliverpb.RegistryType\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"5\n\rRegistryWrite\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"u\n\x14RegistryCreateKeyReq\x12\x0c\n\x04Hive\x18\x01 \x01(\t\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12\x10\n\x08Hostname\x18\x04 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"9\n\x11RegistryCreateKey\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"1\n\x06Tunnel\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12\x11\n\tSessionID\x18\t \x01(\r\"e\n\nTunnelData\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\x12\x0e\n\x06\x43losed\x18\x02 \x01(\x08\x12\x10\n\x08Sequence\x18\x03 \x01(\x04\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12\x11\n\tSessionID\x18\t \x01(\r\"r\n\x08ShellReq\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x11\n\tEnablePTY\x18\x02 \x01(\x08\x12\x0b\n\x03Pid\x18\x03 \x01(\r\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"q\n\x05Shell\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x11\n\tEnablePTY\x18\x02 \x01(\x08\x12\x0b\n\x03Pid\x18\x03 \x01(\r\x12\x14\n\x08TunnelID\x18\x08 \x01(\x04\x42\x02\x30\x01\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"E\n\rNamedPipesReq\x12\x10\n\x08PipeName\x18\x10 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"C\n\nNamedPipes\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"B\n\x0bTCPPivotReq\x12\x0f\n\x07\x41\x64\x64ress\x18\x10 \x01(\t\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"A\n\x08TCPPivot\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response\"[\n\tPivotOpen\x12\x0f\n\x07PivotID\x18\x0c \x01(\r\x12\x11\n\tPivotType\x18\r \x01(\t\x12\x15\n\rRemoteAddress\x18\x0e \x01(\t\x12\x13\n\x0bRegisterMsg\x18\x0f \x01(\x0c\"*\n\nPivotClose\x12\x0f\n\x07PivotID\x18\x0c \x01(\r\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\"*\n\tPivotData\x12\x0f\n\x07PivotID\x18\x0c \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\"*\n\nPivotEntry\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x0e\n\x06Remote\x18\x02 \x01(\t\"2\n\x0cPivotListReq\x12\"\n\x07Request\x18\t \x01(\x0b\x32\x11.commonpb.Request\"X\n\tPivotList\x12%\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\x14.sliverpb.PivotEntry\x12$\n\x08Response\x18\t \x01(\x0b\x32\x12.commonpb.Response*<\n\x0cRegistryType\x12\n\n\x06\x42INARY\x10\x00\x12\n\n\x06STRING\x10\x01\x12\t\n\x05\x44WORD\x10\x02\x12\t\n\x05QWORD\x10\x03\x42/Z-github.com/bishopfox/sliver/protobuf/sliverpbb\x06proto3'
  ,
  dependencies=[commonpb_dot_common__pb2.DESCRIPTOR,])

_REGISTRYTYPE = _descriptor.EnumDescriptor(
  name='RegistryType',
  full_name='sliverpb.RegistryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DWORD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QWORD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7664,
  serialized_end=7724,
)
_sym_db.RegisterEnumDescriptor(_REGISTRYTYPE)

RegistryType = enum_type_wrapper.EnumTypeWrapper(_REGISTRYTYPE)
BINARY = 0
STRING = 1
DWORD = 2
QWORD = 3



_ENVELOPE = _descriptor.Descriptor(
  name='Envelope',
  full_name='sliverpb.Envelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='sliverpb.Envelope.ID', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Type', full_name='sliverpb.Envelope.Type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.Envelope.Data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UnknownMessageType', full_name='sliverpb.Envelope.UnknownMessageType', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=136,
)


_REGISTER = _descriptor.Descriptor(
  name='Register',
  full_name='sliverpb.Register',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='sliverpb.Register.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Hostname', full_name='sliverpb.Register.Hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Uuid', full_name='sliverpb.Register.Uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Username', full_name='sliverpb.Register.Username', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Uid', full_name='sliverpb.Register.Uid', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Gid', full_name='sliverpb.Register.Gid', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Os', full_name='sliverpb.Register.Os', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Arch', full_name='sliverpb.Register.Arch', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Pid', full_name='sliverpb.Register.Pid', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Filename', full_name='sliverpb.Register.Filename', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ActiveC2', full_name='sliverpb.Register.ActiveC2', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Version', full_name='sliverpb.Register.Version', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReconnectInterval', full_name='sliverpb.Register.ReconnectInterval', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProxyURL', full_name='sliverpb.Register.ProxyURL', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=376,
)


_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='sliverpb.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Nonce', full_name='sliverpb.Ping.Nonce', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Ping.Response', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.Ping.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=473,
)


_KILLSESSIONREQ = _descriptor.Descriptor(
  name='KillSessionReq',
  full_name='sliverpb.KillSessionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Force', full_name='sliverpb.KillSessionReq.Force', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.KillSessionReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=542,
)


_PSREQ = _descriptor.Descriptor(
  name='PsReq',
  full_name='sliverpb.PsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.PsReq.Request', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=587,
)


_PS = _descriptor.Descriptor(
  name='Ps',
  full_name='sliverpb.Ps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Processes', full_name='sliverpb.Ps.Processes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Ps.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=589,
  serialized_end=669,
)


_TERMINATEREQ = _descriptor.Descriptor(
  name='TerminateReq',
  full_name='sliverpb.TerminateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Pid', full_name='sliverpb.TerminateReq.Pid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Force', full_name='sliverpb.TerminateReq.Force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.TerminateReq.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=671,
  serialized_end=749,
)


_TERMINATE = _descriptor.Descriptor(
  name='Terminate',
  full_name='sliverpb.Terminate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Pid', full_name='sliverpb.Terminate.Pid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Terminate.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=813,
)


_IFCONFIGREQ = _descriptor.Descriptor(
  name='IfconfigReq',
  full_name='sliverpb.IfconfigReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.IfconfigReq.Request', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=864,
)


_IFCONFIG = _descriptor.Descriptor(
  name='Ifconfig',
  full_name='sliverpb.Ifconfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='NetInterfaces', full_name='sliverpb.Ifconfig.NetInterfaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Ifconfig.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=961,
)


_NETINTERFACE = _descriptor.Descriptor(
  name='NetInterface',
  full_name='sliverpb.NetInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Index', full_name='sliverpb.NetInterface.Index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='sliverpb.NetInterface.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='MAC', full_name='sliverpb.NetInterface.MAC', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IPAddresses', full_name='sliverpb.NetInterface.IPAddresses', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1040,
)


_LSREQ = _descriptor.Descriptor(
  name='LsReq',
  full_name='sliverpb.LsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.LsReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.LsReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1099,
)


_LS = _descriptor.Descriptor(
  name='Ls',
  full_name='sliverpb.Ls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.Ls.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Exists', full_name='sliverpb.Ls.Exists', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Files', full_name='sliverpb.Ls.Files', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Ls.Response', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1208,
)


_FILEINFO = _descriptor.Descriptor(
  name='FileInfo',
  full_name='sliverpb.FileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='sliverpb.FileInfo.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsDir', full_name='sliverpb.FileInfo.IsDir', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Size', full_name='sliverpb.FileInfo.Size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1263,
)


_CDREQ = _descriptor.Descriptor(
  name='CdReq',
  full_name='sliverpb.CdReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.CdReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.CdReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1265,
  serialized_end=1322,
)


_PWDREQ = _descriptor.Descriptor(
  name='PwdReq',
  full_name='sliverpb.PwdReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.PwdReq.Request', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1324,
  serialized_end=1368,
)


_PWD = _descriptor.Descriptor(
  name='Pwd',
  full_name='sliverpb.Pwd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.Pwd.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Pwd.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1370,
  serialized_end=1427,
)


_RMREQ = _descriptor.Descriptor(
  name='RmReq',
  full_name='sliverpb.RmReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.RmReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Recursive', full_name='sliverpb.RmReq.Recursive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Force', full_name='sliverpb.RmReq.Force', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.RmReq.Request', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1429,
  serialized_end=1520,
)


_RM = _descriptor.Descriptor(
  name='Rm',
  full_name='sliverpb.Rm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.Rm.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Rm.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1522,
  serialized_end=1578,
)


_MKDIRREQ = _descriptor.Descriptor(
  name='MkdirReq',
  full_name='sliverpb.MkdirReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.MkdirReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.MkdirReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1580,
  serialized_end=1640,
)


_MKDIR = _descriptor.Descriptor(
  name='Mkdir',
  full_name='sliverpb.Mkdir',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.Mkdir.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Mkdir.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1642,
  serialized_end=1701,
)


_DOWNLOADREQ = _descriptor.Descriptor(
  name='DownloadReq',
  full_name='sliverpb.DownloadReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.DownloadReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.DownloadReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1703,
  serialized_end=1766,
)


_DOWNLOAD = _descriptor.Descriptor(
  name='Download',
  full_name='sliverpb.Download',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.Download.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Encoder', full_name='sliverpb.Download.Encoder', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Exists', full_name='sliverpb.Download.Exists', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.Download.Data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Download.Response', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1768,
  serialized_end=1877,
)


_UPLOADREQ = _descriptor.Descriptor(
  name='UploadReq',
  full_name='sliverpb.UploadReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.UploadReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Encoder', full_name='sliverpb.UploadReq.Encoder', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.UploadReq.Data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.UploadReq.Request', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1879,
  serialized_end=1971,
)


_UPLOAD = _descriptor.Descriptor(
  name='Upload',
  full_name='sliverpb.Upload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.Upload.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Upload.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1973,
  serialized_end=2033,
)


_PROCESSDUMPREQ = _descriptor.Descriptor(
  name='ProcessDumpReq',
  full_name='sliverpb.ProcessDumpReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Pid', full_name='sliverpb.ProcessDumpReq.Pid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Timeout', full_name='sliverpb.ProcessDumpReq.Timeout', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.ProcessDumpReq.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2035,
  serialized_end=2117,
)


_PROCESSDUMP = _descriptor.Descriptor(
  name='ProcessDump',
  full_name='sliverpb.ProcessDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.ProcessDump.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.ProcessDump.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2119,
  serialized_end=2184,
)


_RUNASREQ = _descriptor.Descriptor(
  name='RunAsReq',
  full_name='sliverpb.RunAsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Username', full_name='sliverpb.RunAsReq.Username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcessName', full_name='sliverpb.RunAsReq.ProcessName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Args', full_name='sliverpb.RunAsReq.Args', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.RunAsReq.Request', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2186,
  serialized_end=2285,
)


_RUNAS = _descriptor.Descriptor(
  name='RunAs',
  full_name='sliverpb.RunAs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Output', full_name='sliverpb.RunAs.Output', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.RunAs.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2287,
  serialized_end=2348,
)


_IMPERSONATEREQ = _descriptor.Descriptor(
  name='ImpersonateReq',
  full_name='sliverpb.ImpersonateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Username', full_name='sliverpb.ImpersonateReq.Username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.ImpersonateReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2350,
  serialized_end=2420,
)


_IMPERSONATE = _descriptor.Descriptor(
  name='Impersonate',
  full_name='sliverpb.Impersonate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Impersonate.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2422,
  serialized_end=2473,
)


_REVTOSELFREQ = _descriptor.Descriptor(
  name='RevToSelfReq',
  full_name='sliverpb.RevToSelfReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.RevToSelfReq.Request', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2475,
  serialized_end=2525,
)


_REVTOSELF = _descriptor.Descriptor(
  name='RevToSelf',
  full_name='sliverpb.RevToSelf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.RevToSelf.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2527,
  serialized_end=2576,
)


_INVOKEGETSYSTEMREQ = _descriptor.Descriptor(
  name='InvokeGetSystemReq',
  full_name='sliverpb.InvokeGetSystemReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.InvokeGetSystemReq.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='HostingProcess', full_name='sliverpb.InvokeGetSystemReq.HostingProcess', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.InvokeGetSystemReq.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2578,
  serialized_end=2672,
)


_GETSYSTEM = _descriptor.Descriptor(
  name='GetSystem',
  full_name='sliverpb.GetSystem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.GetSystem.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2674,
  serialized_end=2723,
)


_MAKETOKENREQ = _descriptor.Descriptor(
  name='MakeTokenReq',
  full_name='sliverpb.MakeTokenReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Username', full_name='sliverpb.MakeTokenReq.Username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Password', full_name='sliverpb.MakeTokenReq.Password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Domain', full_name='sliverpb.MakeTokenReq.Domain', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.MakeTokenReq.Request', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2725,
  serialized_end=2827,
)


_MAKETOKEN = _descriptor.Descriptor(
  name='MakeToken',
  full_name='sliverpb.MakeToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.MakeToken.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2829,
  serialized_end=2878,
)


_TASKREQ = _descriptor.Descriptor(
  name='TaskReq',
  full_name='sliverpb.TaskReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Encoder', full_name='sliverpb.TaskReq.Encoder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RWXPages', full_name='sliverpb.TaskReq.RWXPages', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Pid', full_name='sliverpb.TaskReq.Pid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.TaskReq.Data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.TaskReq.Request', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2880,
  serialized_end=2987,
)


_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='sliverpb.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Task.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2989,
  serialized_end=3033,
)


_EXECUTEASSEMBLYREQ = _descriptor.Descriptor(
  name='ExecuteAssemblyReq',
  full_name='sliverpb.ExecuteAssemblyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Assembly', full_name='sliverpb.ExecuteAssemblyReq.Assembly', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Arguments', full_name='sliverpb.ExecuteAssemblyReq.Arguments', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Process', full_name='sliverpb.ExecuteAssemblyReq.Process', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsDLL', full_name='sliverpb.ExecuteAssemblyReq.IsDLL', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Arch', full_name='sliverpb.ExecuteAssemblyReq.Arch', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ClassName', full_name='sliverpb.ExecuteAssemblyReq.ClassName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Method', full_name='sliverpb.ExecuteAssemblyReq.Method', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AppDomain', full_name='sliverpb.ExecuteAssemblyReq.AppDomain', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.ExecuteAssemblyReq.Request', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3036,
  serialized_end=3229,
)


_INVOKEEXECUTEASSEMBLYREQ = _descriptor.Descriptor(
  name='InvokeExecuteAssemblyReq',
  full_name='sliverpb.InvokeExecuteAssemblyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.InvokeExecuteAssemblyReq.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process', full_name='sliverpb.InvokeExecuteAssemblyReq.process', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.InvokeExecuteAssemblyReq.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3231,
  serialized_end=3324,
)


_EXECUTEASSEMBLY = _descriptor.Descriptor(
  name='ExecuteAssembly',
  full_name='sliverpb.ExecuteAssembly',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Output', full_name='sliverpb.ExecuteAssembly.Output', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.ExecuteAssembly.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3326,
  serialized_end=3397,
)


_INVOKEMIGRATEREQ = _descriptor.Descriptor(
  name='InvokeMigrateReq',
  full_name='sliverpb.InvokeMigrateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Pid', full_name='sliverpb.InvokeMigrateReq.Pid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.InvokeMigrateReq.Data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.InvokeMigrateReq.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3399,
  serialized_end=3480,
)


_MIGRATE = _descriptor.Descriptor(
  name='Migrate',
  full_name='sliverpb.Migrate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='sliverpb.Migrate.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Migrate.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3482,
  serialized_end=3546,
)


_EXECUTEREQ = _descriptor.Descriptor(
  name='ExecuteReq',
  full_name='sliverpb.ExecuteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.ExecuteReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Args', full_name='sliverpb.ExecuteReq.Args', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Output', full_name='sliverpb.ExecuteReq.Output', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.ExecuteReq.Request', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3548,
  serialized_end=3640,
)


_EXECUTETOKENREQ = _descriptor.Descriptor(
  name='ExecuteTokenReq',
  full_name='sliverpb.ExecuteTokenReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.ExecuteTokenReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Args', full_name='sliverpb.ExecuteTokenReq.Args', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Output', full_name='sliverpb.ExecuteTokenReq.Output', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.ExecuteTokenReq.Request', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3642,
  serialized_end=3739,
)


_EXECUTE = _descriptor.Descriptor(
  name='Execute',
  full_name='sliverpb.Execute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Result', full_name='sliverpb.Execute.Result', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Status', full_name='sliverpb.Execute.Status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Execute.Response', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3741,
  serialized_end=3820,
)


_SIDELOADREQ = _descriptor.Descriptor(
  name='SideloadReq',
  full_name='sliverpb.SideloadReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.SideloadReq.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcessName', full_name='sliverpb.SideloadReq.ProcessName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Args', full_name='sliverpb.SideloadReq.Args', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='EntryPoint', full_name='sliverpb.SideloadReq.EntryPoint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Kill', full_name='sliverpb.SideloadReq.Kill', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.SideloadReq.Request', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3823,
  serialized_end=3955,
)


_SIDELOAD = _descriptor.Descriptor(
  name='Sideload',
  full_name='sliverpb.Sideload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Result', full_name='sliverpb.Sideload.Result', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Sideload.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3957,
  serialized_end=4021,
)


_INVOKESPAWNDLLREQ = _descriptor.Descriptor(
  name='InvokeSpawnDllReq',
  full_name='sliverpb.InvokeSpawnDllReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.InvokeSpawnDllReq.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcessName', full_name='sliverpb.InvokeSpawnDllReq.ProcessName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Args', full_name='sliverpb.InvokeSpawnDllReq.Args', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='EntryPoint', full_name='sliverpb.InvokeSpawnDllReq.EntryPoint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Kill', full_name='sliverpb.InvokeSpawnDllReq.Kill', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.InvokeSpawnDllReq.Request', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4024,
  serialized_end=4162,
)


_SPAWNDLLREQ = _descriptor.Descriptor(
  name='SpawnDllReq',
  full_name='sliverpb.SpawnDllReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.SpawnDllReq.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcessName', full_name='sliverpb.SpawnDllReq.ProcessName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Offset', full_name='sliverpb.SpawnDllReq.Offset', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Args', full_name='sliverpb.SpawnDllReq.Args', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Kill', full_name='sliverpb.SpawnDllReq.Kill', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.SpawnDllReq.Request', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4165,
  serialized_end=4293,
)


_SPAWNDLL = _descriptor.Descriptor(
  name='SpawnDll',
  full_name='sliverpb.SpawnDll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Result', full_name='sliverpb.SpawnDll.Result', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.SpawnDll.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4295,
  serialized_end=4359,
)


_NETSTATREQ = _descriptor.Descriptor(
  name='NetstatReq',
  full_name='sliverpb.NetstatReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='TCP', full_name='sliverpb.NetstatReq.TCP', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UDP', full_name='sliverpb.NetstatReq.UDP', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IP4', full_name='sliverpb.NetstatReq.IP4', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IP6', full_name='sliverpb.NetstatReq.IP6', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Listening', full_name='sliverpb.NetstatReq.Listening', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.NetstatReq.Request', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4361,
  serialized_end=4480,
)


_SOCKTABENTRY_SOCKADDR = _descriptor.Descriptor(
  name='SockAddr',
  full_name='sliverpb.SockTabEntry.SockAddr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ip', full_name='sliverpb.SockTabEntry.SockAddr.Ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Port', full_name='sliverpb.SockTabEntry.SockAddr.Port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4688,
  serialized_end=4724,
)

_SOCKTABENTRY = _descriptor.Descriptor(
  name='SockTabEntry',
  full_name='sliverpb.SockTabEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='LocalAddr', full_name='sliverpb.SockTabEntry.LocalAddr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RemoteAddr', full_name='sliverpb.SockTabEntry.RemoteAddr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SkState', full_name='sliverpb.SockTabEntry.SkState', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UID', full_name='sliverpb.SockTabEntry.UID', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Process', full_name='sliverpb.SockTabEntry.Process', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Protocol', full_name='sliverpb.SockTabEntry.Protocol', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOCKTABENTRY_SOCKADDR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4483,
  serialized_end=4724,
)


_NETSTAT = _descriptor.Descriptor(
  name='Netstat',
  full_name='sliverpb.Netstat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Entries', full_name='sliverpb.Netstat.Entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Netstat.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4726,
  serialized_end=4814,
)


_ENVREQ = _descriptor.Descriptor(
  name='EnvReq',
  full_name='sliverpb.EnvReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='sliverpb.EnvReq.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.EnvReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4816,
  serialized_end=4874,
)


_ENVINFO = _descriptor.Descriptor(
  name='EnvInfo',
  full_name='sliverpb.EnvInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Variables', full_name='sliverpb.EnvInfo.Variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.EnvInfo.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4876,
  serialized_end=4960,
)


_SETENVREQ = _descriptor.Descriptor(
  name='SetEnvReq',
  full_name='sliverpb.SetEnvReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Variable', full_name='sliverpb.SetEnvReq.Variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.SetEnvReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4962,
  serialized_end=5045,
)


_SETENV = _descriptor.Descriptor(
  name='SetEnv',
  full_name='sliverpb.SetEnv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.SetEnv.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5047,
  serialized_end=5093,
)


_DNSSESSIONINIT = _descriptor.Descriptor(
  name='DNSSessionInit',
  full_name='sliverpb.DNSSessionInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Key', full_name='sliverpb.DNSSessionInit.Key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5095,
  serialized_end=5124,
)


_DNSPOLL = _descriptor.Descriptor(
  name='DNSPoll',
  full_name='sliverpb.DNSPoll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='sliverpb.DNSPoll.blocks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5126,
  serialized_end=5177,
)


_DNSBLOCKHEADER = _descriptor.Descriptor(
  name='DNSBlockHeader',
  full_name='sliverpb.DNSBlockHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='sliverpb.DNSBlockHeader.ID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Size', full_name='sliverpb.DNSBlockHeader.Size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5179,
  serialized_end=5221,
)


_HTTPSESSIONINIT = _descriptor.Descriptor(
  name='HTTPSessionInit',
  full_name='sliverpb.HTTPSessionInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Key', full_name='sliverpb.HTTPSessionInit.Key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5223,
  serialized_end=5253,
)


_SCREENSHOTREQ = _descriptor.Descriptor(
  name='ScreenshotReq',
  full_name='sliverpb.ScreenshotReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.ScreenshotReq.Request', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5255,
  serialized_end=5306,
)


_SCREENSHOT = _descriptor.Descriptor(
  name='Screenshot',
  full_name='sliverpb.Screenshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.Screenshot.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Screenshot.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5308,
  serialized_end=5372,
)


_STARTSERVICEREQ = _descriptor.Descriptor(
  name='StartServiceReq',
  full_name='sliverpb.StartServiceReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ServiceName', full_name='sliverpb.StartServiceReq.ServiceName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ServiceDescription', full_name='sliverpb.StartServiceReq.ServiceDescription', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='BinPath', full_name='sliverpb.StartServiceReq.BinPath', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Hostname', full_name='sliverpb.StartServiceReq.Hostname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Arguments', full_name='sliverpb.StartServiceReq.Arguments', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.StartServiceReq.Request', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5375,
  serialized_end=5531,
)


_SERVICEINFO = _descriptor.Descriptor(
  name='ServiceInfo',
  full_name='sliverpb.ServiceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.ServiceInfo.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5533,
  serialized_end=5584,
)


_SERVICEINFOREQ = _descriptor.Descriptor(
  name='ServiceInfoReq',
  full_name='sliverpb.ServiceInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ServiceName', full_name='sliverpb.ServiceInfoReq.ServiceName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Hostname', full_name='sliverpb.ServiceInfoReq.Hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5586,
  serialized_end=5641,
)


_STOPSERVICEREQ = _descriptor.Descriptor(
  name='StopServiceReq',
  full_name='sliverpb.StopServiceReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ServiceInfo', full_name='sliverpb.StopServiceReq.ServiceInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.StopServiceReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5643,
  serialized_end=5742,
)


_REMOVESERVICEREQ = _descriptor.Descriptor(
  name='RemoveServiceReq',
  full_name='sliverpb.RemoveServiceReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ServiceInfo', full_name='sliverpb.RemoveServiceReq.ServiceInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.RemoveServiceReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5744,
  serialized_end=5845,
)


_BACKDOORREQ = _descriptor.Descriptor(
  name='BackdoorReq',
  full_name='sliverpb.BackdoorReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='FilePath', full_name='sliverpb.BackdoorReq.FilePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProfileName', full_name='sliverpb.BackdoorReq.ProfileName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.BackdoorReq.Request', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5847,
  serialized_end=5935,
)


_BACKDOOR = _descriptor.Descriptor(
  name='Backdoor',
  full_name='sliverpb.Backdoor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Backdoor.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5937,
  serialized_end=5985,
)


_REGISTRYREADREQ = _descriptor.Descriptor(
  name='RegistryReadReq',
  full_name='sliverpb.RegistryReadReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Hive', full_name='sliverpb.RegistryReadReq.Hive', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.RegistryReadReq.Path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Key', full_name='sliverpb.RegistryReadReq.Key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Hostname', full_name='sliverpb.RegistryReadReq.Hostname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.RegistryReadReq.Request', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5987,
  serialized_end=6099,
)


_REGISTRYREAD = _descriptor.Descriptor(
  name='RegistryRead',
  full_name='sliverpb.RegistryRead',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Value', full_name='sliverpb.RegistryRead.Value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.RegistryRead.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6101,
  serialized_end=6168,
)


_REGISTRYWRITEREQ = _descriptor.Descriptor(
  name='RegistryWriteReq',
  full_name='sliverpb.RegistryWriteReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Hive', full_name='sliverpb.RegistryWriteReq.Hive', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.RegistryWriteReq.Path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Key', full_name='sliverpb.RegistryWriteReq.Key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Hostname', full_name='sliverpb.RegistryWriteReq.Hostname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='StringValue', full_name='sliverpb.RegistryWriteReq.StringValue', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ByteValue', full_name='sliverpb.RegistryWriteReq.ByteValue', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='DWordValue', full_name='sliverpb.RegistryWriteReq.DWordValue', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='QWordValue', full_name='sliverpb.RegistryWriteReq.QWordValue', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Type', full_name='sliverpb.RegistryWriteReq.Type', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.RegistryWriteReq.Request', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6171,
  serialized_end=6402,
)


_REGISTRYWRITE = _descriptor.Descriptor(
  name='RegistryWrite',
  full_name='sliverpb.RegistryWrite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.RegistryWrite.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6404,
  serialized_end=6457,
)


_REGISTRYCREATEKEYREQ = _descriptor.Descriptor(
  name='RegistryCreateKeyReq',
  full_name='sliverpb.RegistryCreateKeyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Hive', full_name='sliverpb.RegistryCreateKeyReq.Hive', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.RegistryCreateKeyReq.Path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Key', full_name='sliverpb.RegistryCreateKeyReq.Key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Hostname', full_name='sliverpb.RegistryCreateKeyReq.Hostname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.RegistryCreateKeyReq.Request', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6459,
  serialized_end=6576,
)


_REGISTRYCREATEKEY = _descriptor.Descriptor(
  name='RegistryCreateKey',
  full_name='sliverpb.RegistryCreateKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.RegistryCreateKey.Response', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6578,
  serialized_end=6635,
)


_TUNNEL = _descriptor.Descriptor(
  name='Tunnel',
  full_name='sliverpb.Tunnel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='TunnelID', full_name='sliverpb.Tunnel.TunnelID', index=0,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SessionID', full_name='sliverpb.Tunnel.SessionID', index=1,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6637,
  serialized_end=6686,
)


_TUNNELDATA = _descriptor.Descriptor(
  name='TunnelData',
  full_name='sliverpb.TunnelData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.TunnelData.Data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Closed', full_name='sliverpb.TunnelData.Closed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Sequence', full_name='sliverpb.TunnelData.Sequence', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TunnelID', full_name='sliverpb.TunnelData.TunnelID', index=3,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SessionID', full_name='sliverpb.TunnelData.SessionID', index=4,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6688,
  serialized_end=6789,
)


_SHELLREQ = _descriptor.Descriptor(
  name='ShellReq',
  full_name='sliverpb.ShellReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.ShellReq.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='EnablePTY', full_name='sliverpb.ShellReq.EnablePTY', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Pid', full_name='sliverpb.ShellReq.Pid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TunnelID', full_name='sliverpb.ShellReq.TunnelID', index=3,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.ShellReq.Request', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6791,
  serialized_end=6905,
)


_SHELL = _descriptor.Descriptor(
  name='Shell',
  full_name='sliverpb.Shell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Path', full_name='sliverpb.Shell.Path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='EnablePTY', full_name='sliverpb.Shell.EnablePTY', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Pid', full_name='sliverpb.Shell.Pid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TunnelID', full_name='sliverpb.Shell.TunnelID', index=3,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.Shell.Response', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6907,
  serialized_end=7020,
)


_NAMEDPIPESREQ = _descriptor.Descriptor(
  name='NamedPipesReq',
  full_name='sliverpb.NamedPipesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='PipeName', full_name='sliverpb.NamedPipesReq.PipeName', index=0,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.NamedPipesReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7022,
  serialized_end=7091,
)


_NAMEDPIPES = _descriptor.Descriptor(
  name='NamedPipes',
  full_name='sliverpb.NamedPipes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='sliverpb.NamedPipes.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.NamedPipes.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7093,
  serialized_end=7160,
)


_TCPPIVOTREQ = _descriptor.Descriptor(
  name='TCPPivotReq',
  full_name='sliverpb.TCPPivotReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Address', full_name='sliverpb.TCPPivotReq.Address', index=0,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.TCPPivotReq.Request', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7162,
  serialized_end=7228,
)


_TCPPIVOT = _descriptor.Descriptor(
  name='TCPPivot',
  full_name='sliverpb.TCPPivot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='sliverpb.TCPPivot.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.TCPPivot.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7230,
  serialized_end=7295,
)


_PIVOTOPEN = _descriptor.Descriptor(
  name='PivotOpen',
  full_name='sliverpb.PivotOpen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='PivotID', full_name='sliverpb.PivotOpen.PivotID', index=0,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PivotType', full_name='sliverpb.PivotOpen.PivotType', index=1,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RemoteAddress', full_name='sliverpb.PivotOpen.RemoteAddress', index=2,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RegisterMsg', full_name='sliverpb.PivotOpen.RegisterMsg', index=3,
      number=15, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7297,
  serialized_end=7388,
)


_PIVOTCLOSE = _descriptor.Descriptor(
  name='PivotClose',
  full_name='sliverpb.PivotClose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='PivotID', full_name='sliverpb.PivotClose.PivotID', index=0,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='sliverpb.PivotClose.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7390,
  serialized_end=7432,
)


_PIVOTDATA = _descriptor.Descriptor(
  name='PivotData',
  full_name='sliverpb.PivotData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='PivotID', full_name='sliverpb.PivotData.PivotID', index=0,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Data', full_name='sliverpb.PivotData.Data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7434,
  serialized_end=7476,
)


_PIVOTENTRY = _descriptor.Descriptor(
  name='PivotEntry',
  full_name='sliverpb.PivotEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Type', full_name='sliverpb.PivotEntry.Type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Remote', full_name='sliverpb.PivotEntry.Remote', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7478,
  serialized_end=7520,
)


_PIVOTLISTREQ = _descriptor.Descriptor(
  name='PivotListReq',
  full_name='sliverpb.PivotListReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Request', full_name='sliverpb.PivotListReq.Request', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7522,
  serialized_end=7572,
)


_PIVOTLIST = _descriptor.Descriptor(
  name='PivotList',
  full_name='sliverpb.PivotList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Entries', full_name='sliverpb.PivotList.Entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Response', full_name='sliverpb.PivotList.Response', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7574,
  serialized_end=7662,
)

_PING.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_PING.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_KILLSESSIONREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_PSREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_PS.fields_by_name['Processes'].message_type = commonpb_dot_common__pb2._PROCESS
_PS.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_TERMINATEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_TERMINATE.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_IFCONFIGREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_IFCONFIG.fields_by_name['NetInterfaces'].message_type = _NETINTERFACE
_IFCONFIG.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_LSREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_LS.fields_by_name['Files'].message_type = _FILEINFO
_LS.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_CDREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_PWDREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_PWD.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_RMREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_RM.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_MKDIRREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_MKDIR.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_DOWNLOADREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_DOWNLOAD.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_UPLOADREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_UPLOAD.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_PROCESSDUMPREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_PROCESSDUMP.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_RUNASREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_RUNAS.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_IMPERSONATEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_IMPERSONATE.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_REVTOSELFREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_REVTOSELF.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_INVOKEGETSYSTEMREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_GETSYSTEM.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_MAKETOKENREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_MAKETOKEN.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_TASKREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_TASK.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_EXECUTEASSEMBLYREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_INVOKEEXECUTEASSEMBLYREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_EXECUTEASSEMBLY.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_INVOKEMIGRATEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_MIGRATE.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_EXECUTEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_EXECUTETOKENREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_EXECUTE.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_SIDELOADREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_SIDELOAD.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_INVOKESPAWNDLLREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_SPAWNDLLREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_SPAWNDLL.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_NETSTATREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_SOCKTABENTRY_SOCKADDR.containing_type = _SOCKTABENTRY
_SOCKTABENTRY.fields_by_name['LocalAddr'].message_type = _SOCKTABENTRY_SOCKADDR
_SOCKTABENTRY.fields_by_name['RemoteAddr'].message_type = _SOCKTABENTRY_SOCKADDR
_SOCKTABENTRY.fields_by_name['Process'].message_type = commonpb_dot_common__pb2._PROCESS
_NETSTAT.fields_by_name['Entries'].message_type = _SOCKTABENTRY
_NETSTAT.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_ENVREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_ENVINFO.fields_by_name['Variables'].message_type = commonpb_dot_common__pb2._ENVVAR
_ENVINFO.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_SETENVREQ.fields_by_name['Variable'].message_type = commonpb_dot_common__pb2._ENVVAR
_SETENVREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_SETENV.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_DNSPOLL.fields_by_name['blocks'].message_type = _DNSBLOCKHEADER
_SCREENSHOTREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_SCREENSHOT.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_STARTSERVICEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_SERVICEINFO.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_STOPSERVICEREQ.fields_by_name['ServiceInfo'].message_type = _SERVICEINFOREQ
_STOPSERVICEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_REMOVESERVICEREQ.fields_by_name['ServiceInfo'].message_type = _SERVICEINFOREQ
_REMOVESERVICEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_BACKDOORREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_BACKDOOR.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_REGISTRYREADREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_REGISTRYREAD.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_REGISTRYWRITEREQ.fields_by_name['Type'].enum_type = _REGISTRYTYPE
_REGISTRYWRITEREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_REGISTRYWRITE.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_REGISTRYCREATEKEYREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_REGISTRYCREATEKEY.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_SHELLREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_SHELL.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_NAMEDPIPESREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_NAMEDPIPES.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_TCPPIVOTREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_TCPPIVOT.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
_PIVOTLISTREQ.fields_by_name['Request'].message_type = commonpb_dot_common__pb2._REQUEST
_PIVOTLIST.fields_by_name['Entries'].message_type = _PIVOTENTRY
_PIVOTLIST.fields_by_name['Response'].message_type = commonpb_dot_common__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['Envelope'] = _ENVELOPE
DESCRIPTOR.message_types_by_name['Register'] = _REGISTER
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['KillSessionReq'] = _KILLSESSIONREQ
DESCRIPTOR.message_types_by_name['PsReq'] = _PSREQ
DESCRIPTOR.message_types_by_name['Ps'] = _PS
DESCRIPTOR.message_types_by_name['TerminateReq'] = _TERMINATEREQ
DESCRIPTOR.message_types_by_name['Terminate'] = _TERMINATE
DESCRIPTOR.message_types_by_name['IfconfigReq'] = _IFCONFIGREQ
DESCRIPTOR.message_types_by_name['Ifconfig'] = _IFCONFIG
DESCRIPTOR.message_types_by_name['NetInterface'] = _NETINTERFACE
DESCRIPTOR.message_types_by_name['LsReq'] = _LSREQ
DESCRIPTOR.message_types_by_name['Ls'] = _LS
DESCRIPTOR.message_types_by_name['FileInfo'] = _FILEINFO
DESCRIPTOR.message_types_by_name['CdReq'] = _CDREQ
DESCRIPTOR.message_types_by_name['PwdReq'] = _PWDREQ
DESCRIPTOR.message_types_by_name['Pwd'] = _PWD
DESCRIPTOR.message_types_by_name['RmReq'] = _RMREQ
DESCRIPTOR.message_types_by_name['Rm'] = _RM
DESCRIPTOR.message_types_by_name['MkdirReq'] = _MKDIRREQ
DESCRIPTOR.message_types_by_name['Mkdir'] = _MKDIR
DESCRIPTOR.message_types_by_name['DownloadReq'] = _DOWNLOADREQ
DESCRIPTOR.message_types_by_name['Download'] = _DOWNLOAD
DESCRIPTOR.message_types_by_name['UploadReq'] = _UPLOADREQ
DESCRIPTOR.message_types_by_name['Upload'] = _UPLOAD
DESCRIPTOR.message_types_by_name['ProcessDumpReq'] = _PROCESSDUMPREQ
DESCRIPTOR.message_types_by_name['ProcessDump'] = _PROCESSDUMP
DESCRIPTOR.message_types_by_name['RunAsReq'] = _RUNASREQ
DESCRIPTOR.message_types_by_name['RunAs'] = _RUNAS
DESCRIPTOR.message_types_by_name['ImpersonateReq'] = _IMPERSONATEREQ
DESCRIPTOR.message_types_by_name['Impersonate'] = _IMPERSONATE
DESCRIPTOR.message_types_by_name['RevToSelfReq'] = _REVTOSELFREQ
DESCRIPTOR.message_types_by_name['RevToSelf'] = _REVTOSELF
DESCRIPTOR.message_types_by_name['InvokeGetSystemReq'] = _INVOKEGETSYSTEMREQ
DESCRIPTOR.message_types_by_name['GetSystem'] = _GETSYSTEM
DESCRIPTOR.message_types_by_name['MakeTokenReq'] = _MAKETOKENREQ
DESCRIPTOR.message_types_by_name['MakeToken'] = _MAKETOKEN
DESCRIPTOR.message_types_by_name['TaskReq'] = _TASKREQ
DESCRIPTOR.message_types_by_name['Task'] = _TASK
DESCRIPTOR.message_types_by_name['ExecuteAssemblyReq'] = _EXECUTEASSEMBLYREQ
DESCRIPTOR.message_types_by_name['InvokeExecuteAssemblyReq'] = _INVOKEEXECUTEASSEMBLYREQ
DESCRIPTOR.message_types_by_name['ExecuteAssembly'] = _EXECUTEASSEMBLY
DESCRIPTOR.message_types_by_name['InvokeMigrateReq'] = _INVOKEMIGRATEREQ
DESCRIPTOR.message_types_by_name['Migrate'] = _MIGRATE
DESCRIPTOR.message_types_by_name['ExecuteReq'] = _EXECUTEREQ
DESCRIPTOR.message_types_by_name['ExecuteTokenReq'] = _EXECUTETOKENREQ
DESCRIPTOR.message_types_by_name['Execute'] = _EXECUTE
DESCRIPTOR.message_types_by_name['SideloadReq'] = _SIDELOADREQ
DESCRIPTOR.message_types_by_name['Sideload'] = _SIDELOAD
DESCRIPTOR.message_types_by_name['InvokeSpawnDllReq'] = _INVOKESPAWNDLLREQ
DESCRIPTOR.message_types_by_name['SpawnDllReq'] = _SPAWNDLLREQ
DESCRIPTOR.message_types_by_name['SpawnDll'] = _SPAWNDLL
DESCRIPTOR.message_types_by_name['NetstatReq'] = _NETSTATREQ
DESCRIPTOR.message_types_by_name['SockTabEntry'] = _SOCKTABENTRY
DESCRIPTOR.message_types_by_name['Netstat'] = _NETSTAT
DESCRIPTOR.message_types_by_name['EnvReq'] = _ENVREQ
DESCRIPTOR.message_types_by_name['EnvInfo'] = _ENVINFO
DESCRIPTOR.message_types_by_name['SetEnvReq'] = _SETENVREQ
DESCRIPTOR.message_types_by_name['SetEnv'] = _SETENV
DESCRIPTOR.message_types_by_name['DNSSessionInit'] = _DNSSESSIONINIT
DESCRIPTOR.message_types_by_name['DNSPoll'] = _DNSPOLL
DESCRIPTOR.message_types_by_name['DNSBlockHeader'] = _DNSBLOCKHEADER
DESCRIPTOR.message_types_by_name['HTTPSessionInit'] = _HTTPSESSIONINIT
DESCRIPTOR.message_types_by_name['ScreenshotReq'] = _SCREENSHOTREQ
DESCRIPTOR.message_types_by_name['Screenshot'] = _SCREENSHOT
DESCRIPTOR.message_types_by_name['StartServiceReq'] = _STARTSERVICEREQ
DESCRIPTOR.message_types_by_name['ServiceInfo'] = _SERVICEINFO
DESCRIPTOR.message_types_by_name['ServiceInfoReq'] = _SERVICEINFOREQ
DESCRIPTOR.message_types_by_name['StopServiceReq'] = _STOPSERVICEREQ
DESCRIPTOR.message_types_by_name['RemoveServiceReq'] = _REMOVESERVICEREQ
DESCRIPTOR.message_types_by_name['BackdoorReq'] = _BACKDOORREQ
DESCRIPTOR.message_types_by_name['Backdoor'] = _BACKDOOR
DESCRIPTOR.message_types_by_name['RegistryReadReq'] = _REGISTRYREADREQ
DESCRIPTOR.message_types_by_name['RegistryRead'] = _REGISTRYREAD
DESCRIPTOR.message_types_by_name['RegistryWriteReq'] = _REGISTRYWRITEREQ
DESCRIPTOR.message_types_by_name['RegistryWrite'] = _REGISTRYWRITE
DESCRIPTOR.message_types_by_name['RegistryCreateKeyReq'] = _REGISTRYCREATEKEYREQ
DESCRIPTOR.message_types_by_name['RegistryCreateKey'] = _REGISTRYCREATEKEY
DESCRIPTOR.message_types_by_name['Tunnel'] = _TUNNEL
DESCRIPTOR.message_types_by_name['TunnelData'] = _TUNNELDATA
DESCRIPTOR.message_types_by_name['ShellReq'] = _SHELLREQ
DESCRIPTOR.message_types_by_name['Shell'] = _SHELL
DESCRIPTOR.message_types_by_name['NamedPipesReq'] = _NAMEDPIPESREQ
DESCRIPTOR.message_types_by_name['NamedPipes'] = _NAMEDPIPES
DESCRIPTOR.message_types_by_name['TCPPivotReq'] = _TCPPIVOTREQ
DESCRIPTOR.message_types_by_name['TCPPivot'] = _TCPPIVOT
DESCRIPTOR.message_types_by_name['PivotOpen'] = _PIVOTOPEN
DESCRIPTOR.message_types_by_name['PivotClose'] = _PIVOTCLOSE
DESCRIPTOR.message_types_by_name['PivotData'] = _PIVOTDATA
DESCRIPTOR.message_types_by_name['PivotEntry'] = _PIVOTENTRY
DESCRIPTOR.message_types_by_name['PivotListReq'] = _PIVOTLISTREQ
DESCRIPTOR.message_types_by_name['PivotList'] = _PIVOTLIST
DESCRIPTOR.enum_types_by_name['RegistryType'] = _REGISTRYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Envelope = _reflection.GeneratedProtocolMessageType('Envelope', (_message.Message,), {
  'DESCRIPTOR' : _ENVELOPE,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Envelope)
  })
_sym_db.RegisterMessage(Envelope)

Register = _reflection.GeneratedProtocolMessageType('Register', (_message.Message,), {
  'DESCRIPTOR' : _REGISTER,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Register)
  })
_sym_db.RegisterMessage(Register)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {
  'DESCRIPTOR' : _PING,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Ping)
  })
_sym_db.RegisterMessage(Ping)

KillSessionReq = _reflection.GeneratedProtocolMessageType('KillSessionReq', (_message.Message,), {
  'DESCRIPTOR' : _KILLSESSIONREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.KillSessionReq)
  })
_sym_db.RegisterMessage(KillSessionReq)

PsReq = _reflection.GeneratedProtocolMessageType('PsReq', (_message.Message,), {
  'DESCRIPTOR' : _PSREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.PsReq)
  })
_sym_db.RegisterMessage(PsReq)

Ps = _reflection.GeneratedProtocolMessageType('Ps', (_message.Message,), {
  'DESCRIPTOR' : _PS,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Ps)
  })
_sym_db.RegisterMessage(Ps)

TerminateReq = _reflection.GeneratedProtocolMessageType('TerminateReq', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATEREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.TerminateReq)
  })
_sym_db.RegisterMessage(TerminateReq)

Terminate = _reflection.GeneratedProtocolMessageType('Terminate', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATE,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Terminate)
  })
_sym_db.RegisterMessage(Terminate)

IfconfigReq = _reflection.GeneratedProtocolMessageType('IfconfigReq', (_message.Message,), {
  'DESCRIPTOR' : _IFCONFIGREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.IfconfigReq)
  })
_sym_db.RegisterMessage(IfconfigReq)

Ifconfig = _reflection.GeneratedProtocolMessageType('Ifconfig', (_message.Message,), {
  'DESCRIPTOR' : _IFCONFIG,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Ifconfig)
  })
_sym_db.RegisterMessage(Ifconfig)

NetInterface = _reflection.GeneratedProtocolMessageType('NetInterface', (_message.Message,), {
  'DESCRIPTOR' : _NETINTERFACE,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.NetInterface)
  })
_sym_db.RegisterMessage(NetInterface)

LsReq = _reflection.GeneratedProtocolMessageType('LsReq', (_message.Message,), {
  'DESCRIPTOR' : _LSREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.LsReq)
  })
_sym_db.RegisterMessage(LsReq)

Ls = _reflection.GeneratedProtocolMessageType('Ls', (_message.Message,), {
  'DESCRIPTOR' : _LS,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Ls)
  })
_sym_db.RegisterMessage(Ls)

FileInfo = _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILEINFO,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.FileInfo)
  })
_sym_db.RegisterMessage(FileInfo)

CdReq = _reflection.GeneratedProtocolMessageType('CdReq', (_message.Message,), {
  'DESCRIPTOR' : _CDREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.CdReq)
  })
_sym_db.RegisterMessage(CdReq)

PwdReq = _reflection.GeneratedProtocolMessageType('PwdReq', (_message.Message,), {
  'DESCRIPTOR' : _PWDREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.PwdReq)
  })
_sym_db.RegisterMessage(PwdReq)

Pwd = _reflection.GeneratedProtocolMessageType('Pwd', (_message.Message,), {
  'DESCRIPTOR' : _PWD,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Pwd)
  })
_sym_db.RegisterMessage(Pwd)

RmReq = _reflection.GeneratedProtocolMessageType('RmReq', (_message.Message,), {
  'DESCRIPTOR' : _RMREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RmReq)
  })
_sym_db.RegisterMessage(RmReq)

Rm = _reflection.GeneratedProtocolMessageType('Rm', (_message.Message,), {
  'DESCRIPTOR' : _RM,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Rm)
  })
_sym_db.RegisterMessage(Rm)

MkdirReq = _reflection.GeneratedProtocolMessageType('MkdirReq', (_message.Message,), {
  'DESCRIPTOR' : _MKDIRREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.MkdirReq)
  })
_sym_db.RegisterMessage(MkdirReq)

Mkdir = _reflection.GeneratedProtocolMessageType('Mkdir', (_message.Message,), {
  'DESCRIPTOR' : _MKDIR,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Mkdir)
  })
_sym_db.RegisterMessage(Mkdir)

DownloadReq = _reflection.GeneratedProtocolMessageType('DownloadReq', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.DownloadReq)
  })
_sym_db.RegisterMessage(DownloadReq)

Download = _reflection.GeneratedProtocolMessageType('Download', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOAD,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Download)
  })
_sym_db.RegisterMessage(Download)

UploadReq = _reflection.GeneratedProtocolMessageType('UploadReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.UploadReq)
  })
_sym_db.RegisterMessage(UploadReq)

Upload = _reflection.GeneratedProtocolMessageType('Upload', (_message.Message,), {
  'DESCRIPTOR' : _UPLOAD,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Upload)
  })
_sym_db.RegisterMessage(Upload)

ProcessDumpReq = _reflection.GeneratedProtocolMessageType('ProcessDumpReq', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSDUMPREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ProcessDumpReq)
  })
_sym_db.RegisterMessage(ProcessDumpReq)

ProcessDump = _reflection.GeneratedProtocolMessageType('ProcessDump', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSDUMP,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ProcessDump)
  })
_sym_db.RegisterMessage(ProcessDump)

RunAsReq = _reflection.GeneratedProtocolMessageType('RunAsReq', (_message.Message,), {
  'DESCRIPTOR' : _RUNASREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RunAsReq)
  })
_sym_db.RegisterMessage(RunAsReq)

RunAs = _reflection.GeneratedProtocolMessageType('RunAs', (_message.Message,), {
  'DESCRIPTOR' : _RUNAS,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RunAs)
  })
_sym_db.RegisterMessage(RunAs)

ImpersonateReq = _reflection.GeneratedProtocolMessageType('ImpersonateReq', (_message.Message,), {
  'DESCRIPTOR' : _IMPERSONATEREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ImpersonateReq)
  })
_sym_db.RegisterMessage(ImpersonateReq)

Impersonate = _reflection.GeneratedProtocolMessageType('Impersonate', (_message.Message,), {
  'DESCRIPTOR' : _IMPERSONATE,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Impersonate)
  })
_sym_db.RegisterMessage(Impersonate)

RevToSelfReq = _reflection.GeneratedProtocolMessageType('RevToSelfReq', (_message.Message,), {
  'DESCRIPTOR' : _REVTOSELFREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RevToSelfReq)
  })
_sym_db.RegisterMessage(RevToSelfReq)

RevToSelf = _reflection.GeneratedProtocolMessageType('RevToSelf', (_message.Message,), {
  'DESCRIPTOR' : _REVTOSELF,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RevToSelf)
  })
_sym_db.RegisterMessage(RevToSelf)

InvokeGetSystemReq = _reflection.GeneratedProtocolMessageType('InvokeGetSystemReq', (_message.Message,), {
  'DESCRIPTOR' : _INVOKEGETSYSTEMREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.InvokeGetSystemReq)
  })
_sym_db.RegisterMessage(InvokeGetSystemReq)

GetSystem = _reflection.GeneratedProtocolMessageType('GetSystem', (_message.Message,), {
  'DESCRIPTOR' : _GETSYSTEM,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.GetSystem)
  })
_sym_db.RegisterMessage(GetSystem)

MakeTokenReq = _reflection.GeneratedProtocolMessageType('MakeTokenReq', (_message.Message,), {
  'DESCRIPTOR' : _MAKETOKENREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.MakeTokenReq)
  })
_sym_db.RegisterMessage(MakeTokenReq)

MakeToken = _reflection.GeneratedProtocolMessageType('MakeToken', (_message.Message,), {
  'DESCRIPTOR' : _MAKETOKEN,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.MakeToken)
  })
_sym_db.RegisterMessage(MakeToken)

TaskReq = _reflection.GeneratedProtocolMessageType('TaskReq', (_message.Message,), {
  'DESCRIPTOR' : _TASKREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.TaskReq)
  })
_sym_db.RegisterMessage(TaskReq)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {
  'DESCRIPTOR' : _TASK,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Task)
  })
_sym_db.RegisterMessage(Task)

ExecuteAssemblyReq = _reflection.GeneratedProtocolMessageType('ExecuteAssemblyReq', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEASSEMBLYREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ExecuteAssemblyReq)
  })
_sym_db.RegisterMessage(ExecuteAssemblyReq)

InvokeExecuteAssemblyReq = _reflection.GeneratedProtocolMessageType('InvokeExecuteAssemblyReq', (_message.Message,), {
  'DESCRIPTOR' : _INVOKEEXECUTEASSEMBLYREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.InvokeExecuteAssemblyReq)
  })
_sym_db.RegisterMessage(InvokeExecuteAssemblyReq)

ExecuteAssembly = _reflection.GeneratedProtocolMessageType('ExecuteAssembly', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEASSEMBLY,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ExecuteAssembly)
  })
_sym_db.RegisterMessage(ExecuteAssembly)

InvokeMigrateReq = _reflection.GeneratedProtocolMessageType('InvokeMigrateReq', (_message.Message,), {
  'DESCRIPTOR' : _INVOKEMIGRATEREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.InvokeMigrateReq)
  })
_sym_db.RegisterMessage(InvokeMigrateReq)

Migrate = _reflection.GeneratedProtocolMessageType('Migrate', (_message.Message,), {
  'DESCRIPTOR' : _MIGRATE,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Migrate)
  })
_sym_db.RegisterMessage(Migrate)

ExecuteReq = _reflection.GeneratedProtocolMessageType('ExecuteReq', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ExecuteReq)
  })
_sym_db.RegisterMessage(ExecuteReq)

ExecuteTokenReq = _reflection.GeneratedProtocolMessageType('ExecuteTokenReq', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTETOKENREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ExecuteTokenReq)
  })
_sym_db.RegisterMessage(ExecuteTokenReq)

Execute = _reflection.GeneratedProtocolMessageType('Execute', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTE,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Execute)
  })
_sym_db.RegisterMessage(Execute)

SideloadReq = _reflection.GeneratedProtocolMessageType('SideloadReq', (_message.Message,), {
  'DESCRIPTOR' : _SIDELOADREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.SideloadReq)
  })
_sym_db.RegisterMessage(SideloadReq)

Sideload = _reflection.GeneratedProtocolMessageType('Sideload', (_message.Message,), {
  'DESCRIPTOR' : _SIDELOAD,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Sideload)
  })
_sym_db.RegisterMessage(Sideload)

InvokeSpawnDllReq = _reflection.GeneratedProtocolMessageType('InvokeSpawnDllReq', (_message.Message,), {
  'DESCRIPTOR' : _INVOKESPAWNDLLREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.InvokeSpawnDllReq)
  })
_sym_db.RegisterMessage(InvokeSpawnDllReq)

SpawnDllReq = _reflection.GeneratedProtocolMessageType('SpawnDllReq', (_message.Message,), {
  'DESCRIPTOR' : _SPAWNDLLREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.SpawnDllReq)
  })
_sym_db.RegisterMessage(SpawnDllReq)

SpawnDll = _reflection.GeneratedProtocolMessageType('SpawnDll', (_message.Message,), {
  'DESCRIPTOR' : _SPAWNDLL,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.SpawnDll)
  })
_sym_db.RegisterMessage(SpawnDll)

NetstatReq = _reflection.GeneratedProtocolMessageType('NetstatReq', (_message.Message,), {
  'DESCRIPTOR' : _NETSTATREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.NetstatReq)
  })
_sym_db.RegisterMessage(NetstatReq)

SockTabEntry = _reflection.GeneratedProtocolMessageType('SockTabEntry', (_message.Message,), {

  'SockAddr' : _reflection.GeneratedProtocolMessageType('SockAddr', (_message.Message,), {
    'DESCRIPTOR' : _SOCKTABENTRY_SOCKADDR,
    '__module__' : 'sliverpb.sliver_pb2'
    # @@protoc_insertion_point(class_scope:sliverpb.SockTabEntry.SockAddr)
    })
  ,
  'DESCRIPTOR' : _SOCKTABENTRY,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.SockTabEntry)
  })
_sym_db.RegisterMessage(SockTabEntry)
_sym_db.RegisterMessage(SockTabEntry.SockAddr)

Netstat = _reflection.GeneratedProtocolMessageType('Netstat', (_message.Message,), {
  'DESCRIPTOR' : _NETSTAT,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Netstat)
  })
_sym_db.RegisterMessage(Netstat)

EnvReq = _reflection.GeneratedProtocolMessageType('EnvReq', (_message.Message,), {
  'DESCRIPTOR' : _ENVREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.EnvReq)
  })
_sym_db.RegisterMessage(EnvReq)

EnvInfo = _reflection.GeneratedProtocolMessageType('EnvInfo', (_message.Message,), {
  'DESCRIPTOR' : _ENVINFO,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.EnvInfo)
  })
_sym_db.RegisterMessage(EnvInfo)

SetEnvReq = _reflection.GeneratedProtocolMessageType('SetEnvReq', (_message.Message,), {
  'DESCRIPTOR' : _SETENVREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.SetEnvReq)
  })
_sym_db.RegisterMessage(SetEnvReq)

SetEnv = _reflection.GeneratedProtocolMessageType('SetEnv', (_message.Message,), {
  'DESCRIPTOR' : _SETENV,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.SetEnv)
  })
_sym_db.RegisterMessage(SetEnv)

DNSSessionInit = _reflection.GeneratedProtocolMessageType('DNSSessionInit', (_message.Message,), {
  'DESCRIPTOR' : _DNSSESSIONINIT,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.DNSSessionInit)
  })
_sym_db.RegisterMessage(DNSSessionInit)

DNSPoll = _reflection.GeneratedProtocolMessageType('DNSPoll', (_message.Message,), {
  'DESCRIPTOR' : _DNSPOLL,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.DNSPoll)
  })
_sym_db.RegisterMessage(DNSPoll)

DNSBlockHeader = _reflection.GeneratedProtocolMessageType('DNSBlockHeader', (_message.Message,), {
  'DESCRIPTOR' : _DNSBLOCKHEADER,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.DNSBlockHeader)
  })
_sym_db.RegisterMessage(DNSBlockHeader)

HTTPSessionInit = _reflection.GeneratedProtocolMessageType('HTTPSessionInit', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSESSIONINIT,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.HTTPSessionInit)
  })
_sym_db.RegisterMessage(HTTPSessionInit)

ScreenshotReq = _reflection.GeneratedProtocolMessageType('ScreenshotReq', (_message.Message,), {
  'DESCRIPTOR' : _SCREENSHOTREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ScreenshotReq)
  })
_sym_db.RegisterMessage(ScreenshotReq)

Screenshot = _reflection.GeneratedProtocolMessageType('Screenshot', (_message.Message,), {
  'DESCRIPTOR' : _SCREENSHOT,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Screenshot)
  })
_sym_db.RegisterMessage(Screenshot)

StartServiceReq = _reflection.GeneratedProtocolMessageType('StartServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _STARTSERVICEREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.StartServiceReq)
  })
_sym_db.RegisterMessage(StartServiceReq)

ServiceInfo = _reflection.GeneratedProtocolMessageType('ServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINFO,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ServiceInfo)
  })
_sym_db.RegisterMessage(ServiceInfo)

ServiceInfoReq = _reflection.GeneratedProtocolMessageType('ServiceInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINFOREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ServiceInfoReq)
  })
_sym_db.RegisterMessage(ServiceInfoReq)

StopServiceReq = _reflection.GeneratedProtocolMessageType('StopServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _STOPSERVICEREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.StopServiceReq)
  })
_sym_db.RegisterMessage(StopServiceReq)

RemoveServiceReq = _reflection.GeneratedProtocolMessageType('RemoveServiceReq', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESERVICEREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RemoveServiceReq)
  })
_sym_db.RegisterMessage(RemoveServiceReq)

BackdoorReq = _reflection.GeneratedProtocolMessageType('BackdoorReq', (_message.Message,), {
  'DESCRIPTOR' : _BACKDOORREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.BackdoorReq)
  })
_sym_db.RegisterMessage(BackdoorReq)

Backdoor = _reflection.GeneratedProtocolMessageType('Backdoor', (_message.Message,), {
  'DESCRIPTOR' : _BACKDOOR,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Backdoor)
  })
_sym_db.RegisterMessage(Backdoor)

RegistryReadReq = _reflection.GeneratedProtocolMessageType('RegistryReadReq', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYREADREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RegistryReadReq)
  })
_sym_db.RegisterMessage(RegistryReadReq)

RegistryRead = _reflection.GeneratedProtocolMessageType('RegistryRead', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYREAD,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RegistryRead)
  })
_sym_db.RegisterMessage(RegistryRead)

RegistryWriteReq = _reflection.GeneratedProtocolMessageType('RegistryWriteReq', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYWRITEREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RegistryWriteReq)
  })
_sym_db.RegisterMessage(RegistryWriteReq)

RegistryWrite = _reflection.GeneratedProtocolMessageType('RegistryWrite', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYWRITE,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RegistryWrite)
  })
_sym_db.RegisterMessage(RegistryWrite)

RegistryCreateKeyReq = _reflection.GeneratedProtocolMessageType('RegistryCreateKeyReq', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREATEKEYREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RegistryCreateKeyReq)
  })
_sym_db.RegisterMessage(RegistryCreateKeyReq)

RegistryCreateKey = _reflection.GeneratedProtocolMessageType('RegistryCreateKey', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREATEKEY,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.RegistryCreateKey)
  })
_sym_db.RegisterMessage(RegistryCreateKey)

Tunnel = _reflection.GeneratedProtocolMessageType('Tunnel', (_message.Message,), {
  'DESCRIPTOR' : _TUNNEL,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Tunnel)
  })
_sym_db.RegisterMessage(Tunnel)

TunnelData = _reflection.GeneratedProtocolMessageType('TunnelData', (_message.Message,), {
  'DESCRIPTOR' : _TUNNELDATA,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.TunnelData)
  })
_sym_db.RegisterMessage(TunnelData)

ShellReq = _reflection.GeneratedProtocolMessageType('ShellReq', (_message.Message,), {
  'DESCRIPTOR' : _SHELLREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.ShellReq)
  })
_sym_db.RegisterMessage(ShellReq)

Shell = _reflection.GeneratedProtocolMessageType('Shell', (_message.Message,), {
  'DESCRIPTOR' : _SHELL,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.Shell)
  })
_sym_db.RegisterMessage(Shell)

NamedPipesReq = _reflection.GeneratedProtocolMessageType('NamedPipesReq', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDPIPESREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.NamedPipesReq)
  })
_sym_db.RegisterMessage(NamedPipesReq)

NamedPipes = _reflection.GeneratedProtocolMessageType('NamedPipes', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDPIPES,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.NamedPipes)
  })
_sym_db.RegisterMessage(NamedPipes)

TCPPivotReq = _reflection.GeneratedProtocolMessageType('TCPPivotReq', (_message.Message,), {
  'DESCRIPTOR' : _TCPPIVOTREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.TCPPivotReq)
  })
_sym_db.RegisterMessage(TCPPivotReq)

TCPPivot = _reflection.GeneratedProtocolMessageType('TCPPivot', (_message.Message,), {
  'DESCRIPTOR' : _TCPPIVOT,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.TCPPivot)
  })
_sym_db.RegisterMessage(TCPPivot)

PivotOpen = _reflection.GeneratedProtocolMessageType('PivotOpen', (_message.Message,), {
  'DESCRIPTOR' : _PIVOTOPEN,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.PivotOpen)
  })
_sym_db.RegisterMessage(PivotOpen)

PivotClose = _reflection.GeneratedProtocolMessageType('PivotClose', (_message.Message,), {
  'DESCRIPTOR' : _PIVOTCLOSE,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.PivotClose)
  })
_sym_db.RegisterMessage(PivotClose)

PivotData = _reflection.GeneratedProtocolMessageType('PivotData', (_message.Message,), {
  'DESCRIPTOR' : _PIVOTDATA,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.PivotData)
  })
_sym_db.RegisterMessage(PivotData)

PivotEntry = _reflection.GeneratedProtocolMessageType('PivotEntry', (_message.Message,), {
  'DESCRIPTOR' : _PIVOTENTRY,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.PivotEntry)
  })
_sym_db.RegisterMessage(PivotEntry)

PivotListReq = _reflection.GeneratedProtocolMessageType('PivotListReq', (_message.Message,), {
  'DESCRIPTOR' : _PIVOTLISTREQ,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.PivotListReq)
  })
_sym_db.RegisterMessage(PivotListReq)

PivotList = _reflection.GeneratedProtocolMessageType('PivotList', (_message.Message,), {
  'DESCRIPTOR' : _PIVOTLIST,
  '__module__' : 'sliverpb.sliver_pb2'
  # @@protoc_insertion_point(class_scope:sliverpb.PivotList)
  })
_sym_db.RegisterMessage(PivotList)


DESCRIPTOR._options = None
_TUNNEL.fields_by_name['TunnelID']._options = None
_TUNNELDATA.fields_by_name['TunnelID']._options = None
_SHELLREQ.fields_by_name['TunnelID']._options = None
_SHELL.fields_by_name['TunnelID']._options = None
# @@protoc_insertion_point(module_scope)
